@@ -444,6 +444,21 @@ class MapParameter(Parameter):
         for key in value:
             new_value[key] = value[key]
 
+    def build_parameter_rest(self, style, value, built_params, label=''):
+        # There's a special case for rest-xml with header locations
+        # that we we need to handle for maps.  If this is not the
+        # case we can defer to the base class's implementation of
+        # map parameters serialization.
+        if style == 'rest-xml' and getattr(self, 'location', '') == 'header':
+            prefix = getattr(self, 'location_name', '') or self.name
+            user_params = value
+            for key, value in user_params.items():
+                full_key_name = prefix + key
+                built_params['headers'][full_key_name] = value
+        else:
+            return super(MapParameter, self).build_parameter_rest(
+                style, value, build_params, label)
+
 
 class StructParameter(Parameter):
 
